==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/cs.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Motiv vzhledu s vysokým kontrastem",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motiv vzhledu s vysokým kontrastem pro usnadnění pohybu po aplikaci. Vizuální kvalita bude snížena, ale čitelnost zvýšena.",
    "Dark theme (beta)" : "Tmavý motiv vzhledu (testovací)",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tmavý motiv vzhledu pro ulevení vašim očím snížením celkové svítivosti a jasu. Zatím ještě není hotové, takže hlaste jakékoli problémy, se kterými se potkáte.",
    "Dyslexia font" : "Písmo pro dyslektiky",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je svobodné písmo navržené pro omezení vlivu některých běžných poruch čtení, způsobených dyslexií.",
    "Accessibility" : "Zpřístupnění",
    "Accessibility options for nextcloud" : "Předvolby Nexcloud pro zpřístupnění",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Poskytuje vícero možností zpřístupnění pro usnadnění používání Nextcloud",
    "Web Content Accessibility Guidelines" : "Doporučení pro přístupnost webového obsahu",
    "our issue tracker" : "náš systém evidence hlášení chyb",
    "our design team" : "náš tým designérů",
    "Enable" : "Zapnout"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-16.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/accessibility/l10n/cs.js <==
OC.L10N.register(
    "accessibility",
    {
    "High contrast theme" : "Motiv vzhledu s vysokým kontrastem",
    "A high contrast theme to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Motiv vzhledu s vysokým kontrastem pro usnadnění pohybu po aplikaci. Vizuální kvalita bude snížena, ale čitelnost zvýšena.",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "Tmavý motiv vzhledu pro ulevení vašim očím snížením celkové svítivosti a jasu. Zatím ještě není hotové, takže hlaste jakékoli problémy, se kterými se potkáte.",
    "Dyslexia font" : "Písmo pro dyslektiky",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic je svobodné písmo navržené pro omezení vlivu některých běžných poruch čtení, způsobených dyslexií.",
    "Accessibility" : "Zpřístupnění",
    "Accessibility options for nextcloud" : "Předvolby Nexcloud pro zpřístupnění",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "Poskytuje vícero možností zpřístupnění pro usnadnění používání Nextcloud",
    "Web Content Accessibility Guidelines" : "Doporučení pro přístupnost webového obsahu",
    "our issue tracker" : "náš systém evidence hlášení chyb",
    "our design team" : "náš tým designérů",
    "Enable" : "Zapnout",
    "Dark theme (beta)" : "Tmavý motiv vzhledu (testovací)",
    "Themes" : "Motivy vzhledu",
    "Fonts" : "Písma",
    "enabled" : "zapnuto"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
